# A file with comments, but no test :(

# It raises an error when processed, because the user must
# take action in this situation:
# 
#     1) fix the file, adding the tests
#     or
#     2) stop sending this file to the tester
