$ echo ' '
 
$ echo '    '
    
$ printf '\t\n'
	
$ printf '\t\t\t\n'
			
$ printf ' \t  \t\t   \n'
 	  		   
$ printf '\n \n  \n   \n    \n\n'

 
  
   
    

$ printf '\n\t\n\t\t\n\t\t\t\n\t\t\t\t\n\n'

	
		
			
				

$ printf '\n'

$ printf '\n\n'


$ printf '\n\n\n\n'




$
