# Configurable prompt with --prompt

prompt$ echo "1"  #=> 1
prompt$ echo "2"
2
prompt$ 

# Series closed with empty prompt

prompt$ echo "3"
3
prompt$

# Series closed with empty prompt (with no trailing space)
