# Some tests may change the current dir.
# This could affect the next tests.
# This could affect the relative path for the next input file.
# To avoid problems, the current dir is always reset when a new test file is read.

$ cd
