$ echo 1 #=> fail
$ echo 2 #=> fail
$ echo 3 #=> fail
$ echo 4 #=> fail
$ echo 5 #=> fail
$ echo 6 #=> fail
$ echo 7 #=> fail
$ echo 8 #=> fail
$ echo 9 #=> fail
$ echo 10 #=> fail
$ echo 11 #=> fail
$ echo 12 #=> fail
$ echo 13 #=> fail
$ echo 14 #=> fail
$ echo 15 #=> fail
$ echo 16 #=> fail
$ echo 17 #=> fail
$ echo 18 #=> fail
$ echo 19 #=> fail
$ echo 20 #=> fail
$ echo 21 #=> fail
$ echo 22 #=> fail
$ echo 23 #=> fail
$ echo 24 #=> fail
$ echo 25 #=> fail
$ echo 26 #=> fail
$ echo 27 #=> fail
$ echo 28 #=> fail
$ echo 29 #=> fail
$ echo 30 #=> fail
$ echo 31 #=> fail
$ echo 32 #=> fail
$ echo 33 #=> fail
$ echo 34 #=> fail
$ echo 35 #=> fail
$ echo 36 #=> fail
$ echo 37 #=> fail
$ echo 38 #=> fail
$ echo 39 #=> fail
$ echo 40 #=> fail
$ echo 41 #=> fail
$ echo 42 #=> fail
$ echo 43 #=> fail
$ echo 44 #=> fail
$ echo 45 #=> fail
$ echo 46 #=> fail
$ echo 47 #=> fail
$ echo 48 #=> fail
$ echo 49 #=> fail
$ echo 50 #=> fail
